@@ -31,7 +31,10 @@ from mercurial import (
 from mercurial.hgweb import webutil, hgweb_mod, hgwebdir_mod
 from mercurial.hgweb.common import paritygen
 
-from urllib.parse import urlparse
+try:
+    from urllib.parse import urlparse
+except ImportError:
+    from urlparse import urlparse
 
 import mistune
 
@@ -115,7 +118,7 @@ def _prettyprintdifflines(context, lines, blockno, lineidprefix, filea, reva,
     seenb = False
 
     for lineno, l in enumerate(lines, 1):
-        match = RE_DIFF.match(l.decode('ascii'))
+        match = RE_DIFF.match(l.decode('utf8'))
         if match is not None:
             ltype = b'difflineat'
             groups = match.groups()
